0.9.9 API documentation: matrix_float3x2_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
matrix_float3x2_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef mat< 3, 2, float, highp > | highp_mat3x2
| 3 columns of 2 components matrix of single-precision floating-point numbers using high precision arithmetic in term of ULPs. More...
typedef mat< 3, 2, float, lowp > | lowp_mat3x2
| 3 columns of 2 components matrix of single-precision floating-point numbers using low precision arithmetic in term of ULPs. More...
typedef mat< 3, 2, float, mediump > | mediump_mat3x2
| 3 columns of 2 components matrix of single-precision floating-point numbers using medium precision arithmetic in term of ULPs. More...

## Detailed Description

Core features

Definition in file matrix_float3x2_precision.hpp.